@@ -31,19 +31,35 @@ setClass('lcMethodCrimCV', contains = 'lcMatrixMethod')
 #' @family lcMethod implementations
 #' @references
 #' \insertRef{nielsen2018crimcv}{latrend}
-lcMethodCrimCV = function(response,
-                          time = getOption('latrend.time'),
-                          id = getOption('latrend.id'),
-                          nClusters = 2,
-                          ...) {
-  lcMethod.call(
-    'lcMethodCrimCV',
-    call = match.call.defaults(),
-    defaults = crimCV::crimCV,
-    excludeArgs = c('Dat', 'ng')
-  )
+lcMethodCrimCV = function(
+  response,
+  time = getOption('latrend.time'),
+  id = getOption('latrend.id'),
+  nClusters = 2,
+  ...
+) {
+  mc = match.call.all()
+  mc$Class = 'lcMethodCrimCV'
+  do.call(new, as.list(mc))
 }
 
+#' @rdname interface-crimCV
+setMethod('getArgumentDefaults', signature('lcMethodCrimCV'), function(object) {
+  c(
+    formals(lcMethodCrimCV),
+    formals(crimCV::crimCV),
+    callNextMethod()
+  )
+})
+
+#' @rdname interface-crimCV
+setMethod('getArgumentExclusions', signature('lcMethodCrimCV'), function(object) {
+  union(
+    callNextMethod(),
+    c('Dat', 'ng')
+  )
+})
+
 #' @rdname interface-crimCV
 #' @inheritParams getName
 setMethod('getName', signature('lcMethodCrimCV'), function(object) 'zero-inflated GBTM using crimcv')
@@ -64,16 +80,13 @@ setMethod('prepareData', signature('lcMethodCrimCV'), function(method, data, ver
 #' @rdname interface-crimCV
 #' @inheritParams fit
 setMethod('fit', signature('lcMethodCrimCV'), function(method, data, envir, verbose, ...) {
-  suppressFun = ifelse(as.logical(verbose), force, capture.output)
   time = timeVariable(method)
 
   args = as.list(method, args = crimCV::crimCV)
   args$Dat = envir$dataMat
   args$ng = method$nClusters
 
-  suppressFun({
-    model = do.call(crimCV::crimCV, args)
-  })
+  model = do.call(crimCV::crimCV, args)
   model$data = envir$dataMat
   model$minTime = min(data[[time]])
   model$durTime = max(data[[time]]) - model$minTime
