@@ -16,6 +16,7 @@ setClass('lcMethodKML', contains = 'lcMatrixMethod')
 #' @param id The name of the trajectory identifier variable.
 #' @param nClusters The number of clusters to estimate.
 #' @param ... Arguments passed to [kml::parALGO] and [kml::kml].
+#'
 #' The following external arguments are ignored: object, nbClusters, parAlgo, toPlot, saveFreq
 #' @examples
 #' library(kml)
@@ -25,19 +26,36 @@ setClass('lcMethodKML', contains = 'lcMatrixMethod')
 #' @references
 #' \insertRef{genolini2015kml}{latrend}
 #' @family lcMethod implementations
-lcMethodKML = function(response,
-                       time = getOption('latrend.time'),
-                       id = getOption('latrend.id'),
-                       nClusters = 2,
-                       ...) {
-  lcMethod.call(
-    'lcMethodKML',
-    call = match.call.defaults(),
-    defaults = c(kml::kml, kml::parALGO),
-    excludeArgs = c('object', 'nbClusters', 'parAlgo', 'toPlot', 'saveFreq')
-  )
+lcMethodKML = function(
+  response,
+  time = getOption('latrend.time'),
+  id = getOption('latrend.id'),
+  nClusters = 2,
+  ...
+) {
+  mc = match.call.all()
+  mc$Class = 'lcMethodKML'
+  do.call(new, as.list(mc))
 }
 
+#' @rdname interface-kml
+setMethod('getArgumentDefaults', signature('lcMethodKML'), function(object) {
+  c(
+    formals(lcMethodKML),
+    formals(kml::kml),
+    formals(kml::parALGO),
+    callNextMethod()
+  )
+})
+
+#' @rdname interface-kml
+setMethod('getArgumentExclusions', signature('lcMethodKML'), function(object) {
+  union(
+    callNextMethod(),
+    c('object', 'nbClusters', 'parAlgo', 'toPlot', 'saveFreq')
+  )
+})
+
 #' @rdname interface-kml
 setMethod('getName', signature('lcMethodKML'), function(object) 'longitudinal k-means (KML)')
 
@@ -49,6 +67,11 @@ setMethod('getShortName', signature('lcMethodKML'), function(object) 'kml')
 setMethod('preFit', signature('lcMethodKML'), function(method, data, envir, verbose, ...) {
   e = callNextMethod()
 
+  # workaround for KmL only using the fast version when meanNA() of the longitudinalData package is specified
+  if (identical(method$centerMethod, meanNA)) {
+    method = update(method, centerMethod = longitudinalData::meanNA)
+  }
+
   valueColumn = responseVariable(method)
 
   # Model specification
@@ -77,29 +100,30 @@ setMethod('fit', signature('lcMethodKML'), function(method, data, envir, verbose
 
   # Helper variables
   valueColumn = responseVariable(method)
-  suppressFun = ifelse(as.logical(verbose), force, capture.output)
 
   if (.Platform$OS.type != 'windows') {
+    # nocov start
     cldFilePresent = file.exists('cld.Rdata')
+    # nocov end
   }
 
   cat(verbose, 'Running kml()...', level = verboseLevels$finest)
-  suppressFun(
-    # note that slowKML throws an error for nbClusters=1
-    kml::kml(
-      cld,
-      nbClusters = method$nClusters,
-      nbRedrawing = method$nbRedrawing,
-      toPlot = 'none',
-      parAlgo = envir$par
-    )
+  # note that slowKML throws an error for nbClusters=1
+  kml::kml(
+    cld,
+    nbClusters = method$nClusters,
+    nbRedrawing = method$nbRedrawing,
+    toPlot = 'none',
+    parAlgo = envir$par
   )
 
   # cleanup
   if (.Platform$OS.type != 'windows' && !cldFilePresent && file.exists('cld.Rdata')) {
+    # nocov start
     suppressWarnings({
       file.remove('cld.Rdata')
     })
+    # nocov end
   }
 
   new(
