@@ -1,19 +1,12 @@
 setClass('lcMethodLMKM', contains = 'lcMethod')
 
-setValidity('lcMethodLMKM', function(object) {
-  assert_that(has_lcMethod_args(object, formalArgs(lcMethodLMKM)))
-
-  if (isArgDefined(object, 'formula')) {
-    assert_that(hasSingleResponse(object$formula))
-  }
-})
-
-
 #' @export
 #' @title Two-step clustering through linear regression modeling and k-means
 #' @inheritParams lcMethodFeature
 #' @inheritParams lcMethodKML
 #' @param formula A `formula` specifying the linear trajectory model.
+#' @param center A  `function` that computes the cluster center based on the original trajectories associated with the respective cluster.
+#' By default, the mean is computed.
 #' @param ... Arguments passed to [stats::lm].
 #' The following external arguments are ignored: x, data, control, centers, trace.
 #' @examples
@@ -21,25 +14,43 @@ setValidity('lcMethodLMKM', function(object) {
 #' method <- lcMethodLMKM(Y ~ Time, id = "Id", time = "Time", nClusters = 3)
 #' model <- latrend(method, latrendData)
 #' @family lcMethod implementations
-lcMethodLMKM = function(formula,
-                        time = getOption('latrend.time'),
-                        id = getOption('latrend.id'),
-                        nClusters = 2,
-                        standardize = scale,
-                        ...) {
-  lcMethod.call(
-    'lcMethodLMKM',
-    call = match.call.defaults(),
-    defaults = c(lm, kmeans),
-    excludeArgs = c('x', 'data', 'control', 'centers', 'trace')
-  )
+lcMethodLMKM = function(
+  formula,
+  time = getOption('latrend.time'),
+  id = getOption('latrend.id'),
+  nClusters = 2,
+  center = meanNA,
+  standardize = scale,
+  ...
+) {
+  mc = match.call.all()
+  mc$Class = 'lcMethodLMKM'
+  do.call(new, as.list(mc))
 }
 
 #' @rdname interface-featureBased
-setMethod('getName', signature('lcMethodLMKM'), function(object) 'glm-kmeans')
+setMethod('getArgumentDefaults', signature('lcMethodLMKM'), function(object) {
+  c(
+    formals(lcMethodLMKM),
+    formals(lm),
+    formals(kmeans),
+    callNextMethod()
+  )
+})
 
 #' @rdname interface-featureBased
-setMethod('getShortName', signature('lcMethodLMKM'), function(object) 'glmkm')
+setMethod('getArgumentExclusions', signature('lcMethodLMKM'), function(object) {
+  union(
+    callNextMethod(),
+    c('x', 'data', 'centers', 'trace')
+  )
+})
+
+#' @rdname interface-featureBased
+setMethod('getName', signature('lcMethodLMKM'), function(object) 'lm-kmeans')
+
+#' @rdname interface-featureBased
+setMethod('getShortName', signature('lcMethodLMKM'), function(object) 'lmkm')
 
 #' @rdname interface-featureBased
 setMethod('prepareData', signature('lcMethodLMKM'), function(method, data, verbose) {
@@ -61,16 +72,21 @@ setMethod('prepareData', signature('lcMethodLMKM'), function(method, data, verbo
 #' @rdname interface-featureBased
 setMethod('fit', signature('lcMethodLMKM'), function(method, data, envir, verbose, ...) {
   cat(verbose, 'Cluster step...')
-  km = kmeans(envir$x,
-              centers = method$nClusters,
-              trace = canShow(verbose, 'fine'))
+  km = kmeans(
+    envir$x,
+    centers = method$nClusters,
+    trace = canShow(verbose, 'fine')
+  )
 
   new(
     'lcModelLMKM',
     method = method,
     data = data,
     model = km,
+    center = method$center,
+    name = 'lmkm',
     coefNames = colnames(envir$x),
+    trajectoryCoefs = envir$x,
     clusterNames = make.clusterNames(method$nClusters)
   )
 })
