@@ -27,6 +27,14 @@ setValidity('lcMethodLcmmGMM', function(object) {
 #' @param classmb The cluster membership formula for the multinomial logistic model. See [lcmm::hlme] for details.
 #' @param time The name of the time variable.
 #' @param id The name of the trajectory identifier variable. This replaces the `subject` argument of [lcmm::hlme].
+#' @param init Alternative for the `B` argument of [lcmm::hlme], for initializing the hlme fitting procedure.
+#' If `"lme.random"` (default): random initialization through a standard linear mixed model.
+#' Assigns a fitted standard linear mixed model enclosed in a call to random() to the `B` argument.
+#' If `"lme"`, fits a standard linear mixed model and passes this to the `B` argument.
+#' If `NULL` or `"default"`, the default [lcmm::hlme] input for `B` is used.
+#'
+#' The argument is ignored if the `B` argument is specified, or `nClusters = 1`.
+#'
 #' @param nClusters The number of clusters to fit. This replaces the `ng` argument of [lcmm::hlme].
 #' @param ... Arguments passed to [lcmm::hlme].
 #' The following arguments are ignored: data, fixed, random, mixture, subject, classmb, returndata, ng, verbose, subset.
@@ -46,83 +54,143 @@ setValidity('lcMethodLcmmGMM', function(object) {
 #' \insertRef{proustlima2017estimation}{latrend}
 #'
 #' \insertRef{proustlima2019lcmm}{latrend}
-lcMethodLcmmGMM = function(fixed,
-                          mixture = ~ 1,
-                          random = ~ 1,
-                          classmb = ~ 1,
-                          time = getOption('latrend.time'),
-                          id = getOption('latrend.id'),
-                          nClusters = 2,
-                          ...) {
-  lcMethod.call(
-    'lcMethodLcmmGMM',
-    call = match.call.all(),
-    defaults = lcmm::hlme,
-    excludeArgs = c(
-      'data',
-      'subject',
-      'returndata',
-      'ng',
-      'verbose',
-      'subset'
-    )
-  )
+lcMethodLcmmGMM = function(
+  fixed,
+  mixture = ~ 1,
+  random = ~ 1,
+  classmb = ~ 1,
+  time = getOption('latrend.time'),
+  id = getOption('latrend.id'),
+  init = 'default',
+  nClusters = 2,
+  ...
+) {
+  mc = match.call.all()
+  mc$Class = 'lcMethodLcmmGMM'
+  do.call(new, as.list(mc))
 }
 
+#' @rdname interface-lcmm
+setMethod('getArgumentDefaults', signature('lcMethodLcmmGMM'), function(object) {
+  c(
+    formals(lcMethodLcmmGMM),
+    formals(lcmm::hlme),
+    callNextMethod()
+  )
+})
+
+#' @rdname interface-lcmm
+setMethod('getArgumentExclusions', signature('lcMethodLcmmGMM'), function(object) {
+  union(
+    callNextMethod(),
+    c('data', 'subject', 'returndata', 'ng', 'verbose', 'subset')
+  )
+})
+
 #' @rdname interface-lcmm
 setMethod('getName', signature('lcMethodLcmmGMM'), function(object) 'growth mixture model')
 
 #' @rdname interface-lcmm
 setMethod('getShortName', signature('lcMethodLcmmGMM'), function(object) 'gmm')
 
+#' @rdname interface-lcmm
+setMethod('validate', 'lcMethodLcmmGMM', function(method, data, envir = NULL, ...) {
+  if (hasCovariates(method$fixed) && not(timeVariable(method) %in% getCovariates(method$fixed))) {
+    warning(
+      sprintf(
+        'The specified time variable "%s" does not occur in the %s argument for "fixed" = %s.',
+        timeVariable(method),
+        class(method)[1],
+        deparse(method$fixed)
+      ),
+      immediate. = TRUE
+    )
+  }
+  return(TRUE)
+})
+
 gmm_prepare = function(method, data, envir, verbose, ...) {
   e = new.env()
   e$verbose = as.logical(verbose)
 
   # Check & process data
   id = idVariable(method)
-  e$data = as.data.table(data) %>%
+  trainData = as.data.table(data) %>%
     .[, c(id) := factor(get(id)) %>% as.integer()]
 
-  # Parameter processing
-  if (length(getCovariates(method$mixture)) == 0 && !hasIntercept(method$mixture)) {
-    if (method$nClusters > 1) {
-      warnings.Verbose(
-        verbose,
-        'no cluster-specific terms specified in formula. Defaulting to intercept.'
-      )
+  # Create argument list
+  args = as.list(method, args = lcmm::hlme)
+  args$data = as.data.frame(trainData)
+  args$subject = idVariable(method)
+  args$classmb = e$classmb = dropIntercept(method$classmb) # drop intercept from formula.mb
+  args$ng = method$nClusters
+  args$verbose = envir$verbose
+  args$returndata = TRUE
+
+  # process mixture formula
+  if (method$nClusters > 1) {
+    if (length(getCovariates(method$mixture)) == 0 && !hasIntercept(method$mixture)) {
+      if (method$nClusters > 1) {
+        warnings.Verbose(
+          verbose,
+          'no cluster-specific terms specified in formula. Defaulting to intercept.'
+        )
+      }
+      args$mixture = as.formula('~1', env = environment(method$mixture))
+    } else {
+      args$mixture = dropResponse(method$mixture)
     }
-    e$mixture = as.formula('~1', env = environment(method$mixture))
   } else {
-    e$mixture = dropResponse(method$mixture)
+    args$mixture = NULL
   }
 
-  # drop intercept from formula.mb
-  e$classmb = dropIntercept(method$classmb)
+  # classmb is not allowed to be specified for ng=1
+  if (method$nClusters == 1 || !hasCovariates(args$classmb)) {
+    args$classmb = NULL
+  }
+
+  if (hasName(method, 'init') && method$nClusters > 1) {
+    init = match.arg(method$init, c('default', 'lme', 'lme.random'))
+
+    switch(init,
+      lme = {
+        cat(verbose, 'Fitting standard linear mixed model for initializing the mixture estimation...')
+        args1 = args
+        args1$ng = 1
+        args1$mixture = NULL
+        args1$classmb = NULL
+
+        args$B = do.call(lcmm::hlme, args1)
+      },
+      lme.random = {
+        cat(verbose, 'Fitting standard linear mixed model for random initialization for the mixture estimation...')
+        args1 = args
+        args1$ng = 1
+        args1$mixture = NULL
+        args1$classmb = NULL
+        e$lme = do.call(lcmm::hlme, args1)
+        args$B = quote(random(lme))
+      }
+    )
+  }
+
+  e$args = args
 
   return(e)
 }
+
 #' @rdname interface-lcmm
 setMethod('preFit', signature('lcMethodLcmmGMM'), gmm_prepare)
 
 ##
 gmm_fit = function(method, data, envir, verbose, ...) {
-  args = as.list(method, args = lcmm::hlme)
-  args$data = as.data.frame(envir$data)
-  if (method$nClusters > 1) {
-    args$mixture = envir$mixture
-  } else {
-    args$mixture = NULL
-  }
-  args$subject = idVariable(method)
-  args$classmb = envir$classmb
-  args$ng = method$nClusters
-  args$verbose = envir$verbose
-  args$returndata = TRUE
+  args = envir$args
 
-  if (method$nClusters == 1 || !hasCovariates(args$classmb)) {
-    # classmb is not allowed to be specified for ng=1
-    args$classmb = NULL
+  if (hasName(envir, 'lme')) {
+    # work-around for eval() of hlme() only considering global and function scope
+    .latrend.lme <- envir$lme
+    # args$B = quote(random(get('.latrend.lme', envir = parent.frame(3))))
+    args$B = quote(random(dynGet('.latrend.lme', inherits = TRUE)))
   }
 
   model = do.call(lcmm::hlme, args)
