@@ -1,7 +1,12 @@
 context('mixAK')
 skip_if_not_installed('mixAK')
+skip_on_cran()
 rngReset()
 
+lcMethodTestMixAK_GLMM = function(...) {
+  lcMethodMixAK_GLMM(fixed = Value ~ 1, random = ~ Assessment, ..., seed = 1)
+}
+
 test_that('default', {
   suppressWarnings({
     m = lcMethodTestMixAK_GLMM(PED = FALSE, nClusters = 2)
