@@ -1,10 +1,8 @@
 context('lcModels')
 
-kml2 = m1 = latrend(lcMethodTestKML(nClusters=2), testLongData)
-kml3 = latrend(lcMethodTestKML(nClusters=3), testLongData)
-kml4 = latrend(lcMethodTestKML(nClusters=4), testLongData)
-gmm = m2 = latrend(lcMethodTestLMKM(nClusters=2), testLongData)
-models = lcModels(group=c(kml2, gmm), kml3, kml4)
+m1 = kml2
+m2 = gmm2
+models = lcModels(group=c(kml2, gmm2), kml3, kml4)
 
 test_that('as', {
   as.lcModels(NULL) %>%
@@ -22,6 +20,8 @@ test_that('as', {
   as.lcModels(c(A=m1, B=m2)) %>%
     expect_length(2) %>%
     expect_named()
+
+  expect_error(as.lcModels(1:2))
 })
 
 test_that('create', {
@@ -93,11 +93,11 @@ test_that('subset', {
     expect_is('lcModels') %>%
     expect_length(4)
 
-  subset(models, .method == 'glmkm') %>%
+  subset(models, .method == 'gmm') %>%
     expect_is('lcModels') %>%
     expect_length(1)
 
-  subset(models, .method == 'glmkm') %>%
+  subset(models, .method == 'gmm') %>%
     expect_length(1)
 
   subset(models, .method == 'kml') %>%
@@ -127,6 +127,12 @@ test_that('single metric', {
   expect_true(names(x) == 'BIC')
 })
 
+test_that('single metric for empty list', {
+  dfOut = metric(list(), 'BIC', drop = FALSE)
+  expect_is(dfOut, 'data.frame')
+  expect_true(nrow(dfOut) == 0)
+})
+
 test_that('multiple metrics', {
   metric(lcModels(), c('AIC', 'BIC')) %>%
     expect_is('numeric') %>%
@@ -142,13 +148,41 @@ test_that('multiple metrics', {
 })
 
 test_that('min', {
-  min(models, 'WRSS') %>%
-    expect_is('lcModel')
+  expect_is(min(models, 'WRSS'), 'lcModel')
+})
+
+test_that('min for empty list', {
+  expect_error(min(as.lcModels(NULL), 'WRSS'))
 })
 
 test_that('max', {
-  max(models, 'WRSS') %>%
-    expect_is('lcModel')
+  expect_is(max(models, 'WRSS'), 'lcModel')
+})
+
+test_that('max for empty list', {
+  expect_error(max(as.lcModels(NULL), 'WRSS'))
+})
+
+test_that('plot', {
+  p = plot(models)
+  expect_is(p, 'grob')
+})
+
+test_that('plot empty list', {
+  expect_warning({
+    p = plot(as.lcModels(list()))
+  })
+})
+
+test_that('plot subset', {
+  p = plot(models, subset = nClusters == 2)
+  expect_is(p, 'grob')
+})
+
+test_that('plot subset with no results', {
+  expect_warning({
+    p = plot(models, subset = nClusters < 1)
+  })
 })
 
 test_that('plotMetric', {
@@ -162,13 +196,64 @@ test_that('plotMetric', {
     expect_is('gg')
 })
 
-test_that('externalMetric of list', {
-  d = externalMetric(models, name = 'adjustedRand')
+test_that('pairwise externalMetric of list', {
+  d = externalMetric(models, 'adjustedRand')
   expect_is(d, 'dist')
 })
 
 test_that('externalMetric against model', {
-  externalMetric(models, models[[1]], name = 'adjustedRand') %>%
-    expect_is('numeric') %>%
-    expect_length(length(models))
+  numOut = externalMetric(models, models[[1]], name = 'adjustedRand')
+  expect_is(numOut, 'numeric')
+  expect_length(numOut, length(models))
+
+  dfOut = externalMetric(models, models[[1]], name = 'adjustedRand', drop = FALSE)
+  expect_is(dfOut, 'data.frame')
+  expect_true(nrow(dfOut) == length(models))
+})
+
+test_that('externalMetric single model against model', {
+  numOut = externalMetric(models[1], models[[1]], name = 'adjustedRand', drop = TRUE)
+  expect_is(numOut, 'numeric')
+  expect_length(numOut, 1)
+
+  dfOut = externalMetric(models[1], models[[1]], name = 'adjustedRand', drop = FALSE)
+  expect_is(dfOut, 'data.frame')
+  expect_true(nrow(dfOut) == 1)
+})
+
+test_that('externalMetric empty list against model', {
+  numOut = externalMetric(list(), models[[1]], name = 'adjustedRand', drop = TRUE)
+  expect_is(numOut, 'numeric')
+  expect_length(numOut, 0)
+
+  dfOut = externalMetric(list(), models[[1]], name = 'adjustedRand', drop = FALSE)
+  expect_is(dfOut, 'data.frame')
+  expect_true(nrow(dfOut) == 0)
+})
+
+test_that('estimationTime', {
+  secs = estimationTime(models)
+  expect_is(secs, 'numeric')
+  expect_length(secs, 1)
+  expect_gt(secs, estimationTime(models[[1]]))
+
+  secs2 = estimationTime(as.list(models))
+  expect_equal(secs, secs2)
+})
+
+test_that('estimationTime with unit argument', {
+  secs = estimationTime(models)
+  mins = estimationTime(models, unit = 'mins')
+  days = estimationTime(models, unit = 'days')
+
+  expect_gt(secs, mins)
+  expect_gt(mins, days)
+})
+
+test_that('print', {
+  expect_output(print(models, summary = FALSE))
+})
+
+test_that('print summary', {
+  expect_output(print(models, summary = TRUE))
 })
